@@ -1,6 +1,6 @@
-__version__ = "0.4.0"
+__version__ = "0.4.1"
 __DOWNLOAD_SERVER__ = 'https://sbert.net/models/'
-from .datasets import SentencesDataset, SentenceLabelDataset, ParallelSentencesDataset
+from .datasets import SentencesDataset, ParallelSentencesDataset
 from .LoggingHandler import LoggingHandler
 from .SentenceTransformer import SentenceTransformer
 from .readers import InputExample
